Crate hime_redist

Crate hime_redist 

This crate provides the redistributable runtime for Hime-generated parsers It contains the runtime APIs for lexers and parsers generated using Hime. For more information about how to generate parsers using Hime, head to Hime. The code for this library is available on GitHub. This software is developed by the Assocation Cénotélie, France.

Usage

This crate is on crates.io and can be used by adding hime_redist to your dependencies in your project’s Cargo.toml.

[dependencies]
hime_redist = "4.0.0"

and this to your crate root:

extern crate hime_redist;

Modules

ast
Module for Abstract-Syntax Trees
errors
Module for the definition of lexical and syntactic errors
lexers
Module for lexers API
parsers
Module for parsers API
result
Module for the definition of a parse result
sppf
Module for Shared-Packed Parse Forest
symbols
Module for the definition of grammar symbols
text
Module for text-handling APIs
tokens
Module for the definition of lexical tokens
utils
Module for utility APIs

Constants

CRATE_VERSION
The version of this program